==> kmonad-0.4.3-33-x86_64.pkg.tar.zst: usr/share/haskell/register/kmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kmonad
version:              0.4.3
visibility:           public
id:                   kmonad-0.4.3-FfnBR88RXfo9j0FLIyEaQ2
key:                  kmonad-0.4.3-FfnBR88RXfo9j0FLIyEaQ2
license:              MIT
maintainer:           janssen.dhj@gmail.com
author:               David Janssen
synopsis:             Advanced keyboard remapping utility
description:
    KMonad is a cross-platform command-line utility that runs as a daemon. It
    captures keyboard input (exactly how depends on the OS) and remaps it. The
    mapping is highly configurable, and provides options like (transparent) layer
    overlays, tap-mod buttons, multi-tap buttons, leader-key style buttons, and
    keyboard macros. Functionality heavily inspired by the QMK-firmware.

category:             Application
abi:                  146f884d20240d1142e607a5a5a7cf06
exposed:              True
exposed-modules:
    KMonad.App KMonad.App.Main KMonad.App.Types KMonad.Args
    KMonad.Args.Cmd KMonad.Args.Joiner KMonad.Args.Parser
    KMonad.Args.TH KMonad.Args.Types KMonad.Gesture KMonad.Keyboard
    KMonad.Keyboard.ComposeSeq KMonad.Keyboard.IO
    KMonad.Keyboard.IO.Linux.DeviceSource
    KMonad.Keyboard.IO.Linux.Types KMonad.Keyboard.IO.Linux.UinputSink
    KMonad.Keyboard.Keycode KMonad.Keyboard.Ops KMonad.Keyboard.Types
    KMonad.Model KMonad.Model.Action KMonad.Model.BEnv
    KMonad.Model.Button KMonad.Model.Dispatch KMonad.Model.Hooks
    KMonad.Model.Keymap KMonad.Model.Sluice KMonad.Parsing
    KMonad.Prelude KMonad.Prelude.Definitions KMonad.Prelude.Imports
    KMonad.Util KMonad.Util.LayerStack KMonad.Util.MultiMap
    Paths_kmonad

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kmonad-0.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kmonad-0.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kmonad-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/kmonad
hs-libraries:         HSkmonad-0.4.3-FfnBR88RXfo9j0FLIyEaQ2
depends:
    base-4.17.2.1 cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    lens-5.2.3-CUB7er19pGW1jvefO3TVCG
    megaparsec-9.6.1-2HDqovyWdJD7TkiDY5U33O mtl-2.2.2
    optparse-applicative-0.17.1.0-3m15PZJ9R8tLZfnW85Yn0z
    resourcet-1.2.6-223TkNfardcC3p5LC28WLD
    rio-0.1.22.0-2BvCPRyYayr3oueX4FPgW2 template-haskell-2.19.0.0
    time-1.12.2 unix-2.7.3 unliftio-0.2.25.1-LfkN9oBuVsC1PSAv8s4AS5

haddock-interfaces:   /usr/share/doc/kmonad/html/kmonad.haddock
haddock-html:         /usr/share/doc/kmonad/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> kmonad-0.4.3-34-x86_64.pkg.tar.zst: usr/share/haskell/register/kmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kmonad
version:              0.4.3
visibility:           public
id:                   kmonad-0.4.3-IB8yvM9WK8B9qZpnWPlYRY
key:                  kmonad-0.4.3-IB8yvM9WK8B9qZpnWPlYRY
license:              MIT
maintainer:           janssen.dhj@gmail.com
author:               David Janssen
synopsis:             Advanced keyboard remapping utility
description:
    KMonad is a cross-platform command-line utility that runs as a daemon. It
    captures keyboard input (exactly how depends on the OS) and remaps it. The
    mapping is highly configurable, and provides options like (transparent) layer
    overlays, tap-mod buttons, multi-tap buttons, leader-key style buttons, and
    keyboard macros. Functionality heavily inspired by the QMK-firmware.

category:             Application
abi:                  5ccc1ed6e82123e533b4ff85bd2516aa
exposed:              True
exposed-modules:
    KMonad.App KMonad.App.Main KMonad.App.Types KMonad.Args
    KMonad.Args.Cmd KMonad.Args.Joiner KMonad.Args.Parser
    KMonad.Args.TH KMonad.Args.Types KMonad.Gesture KMonad.Keyboard
    KMonad.Keyboard.ComposeSeq KMonad.Keyboard.IO
    KMonad.Keyboard.IO.Linux.DeviceSource
    KMonad.Keyboard.IO.Linux.Types KMonad.Keyboard.IO.Linux.UinputSink
    KMonad.Keyboard.Keycode KMonad.Keyboard.Ops KMonad.Keyboard.Types
    KMonad.Model KMonad.Model.Action KMonad.Model.BEnv
    KMonad.Model.Button KMonad.Model.Dispatch KMonad.Model.Hooks
    KMonad.Model.Keymap KMonad.Model.Sluice KMonad.Parsing
    KMonad.Prelude KMonad.Prelude.Definitions KMonad.Prelude.Imports
    KMonad.Util KMonad.Util.LayerStack KMonad.Util.MultiMap
    Paths_kmonad

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kmonad-0.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kmonad-0.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kmonad-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/kmonad
hs-libraries:         HSkmonad-0.4.3-IB8yvM9WK8B9qZpnWPlYRY
depends:
    base-4.17.2.1 cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    lens-5.2.3-9GV2xnL92otDGMRfTuRDyv
    megaparsec-9.6.1-2HDqovyWdJD7TkiDY5U33O mtl-2.2.2
    optparse-applicative-0.17.1.0-3m15PZJ9R8tLZfnW85Yn0z
    resourcet-1.2.6-223TkNfardcC3p5LC28WLD
    rio-0.1.22.0-LSzD5VOqa8N1YSUCy1BrHD template-haskell-2.19.0.0
    time-1.12.2 unix-2.7.3 unliftio-0.2.25.1-LfkN9oBuVsC1PSAv8s4AS5

haddock-interfaces:   /usr/share/doc/kmonad/html/kmonad.haddock
haddock-html:         /usr/share/doc/kmonad/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
